@@ -33,7 +33,7 @@ import subprocess
 import argparse
 import io
 
-system_version = "2.4.9"  # This MUST MATCH the version specified in setup.py
+system_version = "2.5.0"  # This MUST MATCH the version specified in setup.py
 api_version = "0.0.3"
 
 IS_PY3 = sys.version_info.major == 3
@@ -50,6 +50,9 @@ else:
     import ConfigParser
     import urllib2
 
+    reload(sys)
+    sys.setdefaultencoding("utf8")
+
     config = ConfigParser.SafeConfigParser()
 
 
@@ -109,7 +112,8 @@ if not os.path.exists(log_locations):
 
 debugging = True
 logging.basicConfig(level=logging.DEBUG,
-                    filename=(log_locations + "/log_" + str(datetime.today().strftime('%Y-%m-%d')) + ".log"))
+                    filename=(log_locations + "/log_" + str(
+                        datetime.today().strftime('%Y-%m-%d')) + ".log"))
 
 now = time.time()
 for filename in os.listdir(log_locations):
@@ -319,7 +323,7 @@ def set_config():
                     "request_url": update_url + "?id=" + get_rpid(),
                     "rpi_id": str(get_rpid()),
                     "printer_id": printer_id,
-                    "printer_name": str(config.get("info", "printer_name")),
+                    "printer_name": config.get("info", "printer_name"),
                     "simplyprint_version": str(system_version),
                     "sp_local_installed": True,
                     "temp_short_setup_id": str(config.get("info", "temp_short_setup_id")),
@@ -926,8 +930,8 @@ def sync_settings_with_plugin():
 
                         hasmodified = True
 
-                    the_check = str(config.get("info", "printer_name"))
-                    printer_name = str(the_data["printer_name"]).strip()
+                    the_check = config.get("info", "printer_name")
+                    printer_name = the_data["printer_name"].encode("utf-8").strip()
 
                     if printer_name != the_check:
                         log("Plugin setting 'printer_name' is not the same as local config"
@@ -935,8 +939,8 @@ def sync_settings_with_plugin():
 
                         hasmodified = True
 
-                    the_check = str(config.get("info", "temp_short_setup_id"))
-                    printer_name = the_data["temp_short_setup_id"].strip()
+                    the_check = config.get("info", "temp_short_setup_id")
+                    printer_name = the_data["temp_short_setup_id"].encode("utf-8").strip()
 
                     if printer_name != the_check:
                         log("Plugin setting 'temp_short_setup_id' is not the same as local config"
