@@ -337,12 +337,12 @@ def do_the_request(num):
                             config_set = True
                             set_config_key("info", "printer_id", str(the_json["printer_id"]))
 
-                        the_printer_name = str(the_json["printer_name"]).strip()
+                        the_printer_name = the_json["printer_name"].encode("utf-8").strip()
                         old_name = config.get("info", "printer_name")
                         if old_name != the_printer_name:
                             config_set = True
-                            log("Updating printer name to; " + str(the_printer_name) + " (old was " + old_name + ")")
-                            set_config_key("info", "printer_name", the_printer_name)
+                            log("Updating printer name to; " + the_printer_name + " (old was " + old_name + ")")
+                            set_config_key("info", "printer_name", the_printer_name.replace("%", "%%"))
 
                         if config_set:
                             set_config()
